==> ejc-signaturemanage-impl-3.0.1-20220719.035047-199-sources.jar: com/ejianc/business/signaturemanage/controller/SignMgrController.java <==
package com.ejianc.business.signaturemanage.controller;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.signaturemanage.service.ISignMgrService;
import com.ejianc.business.signaturemanage.service.ISignMgrSignatoryService;
import com.ejianc.business.signaturemanage.vo.PrivateSignUrlVO;
import com.ejianc.business.signaturemanage.vo.SignatureCenterVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.api.IUserApi;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.usercenter.vo.UserVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import net.qiyuesuo.sdk.bean.contract.ContractDetail;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.io.Serializable;

/**
 * 签章中心
 */
@RestController
@RequestMapping("/signatureCenter")
public class SignMgrController implements Serializable {
	private static final long serialVersionUID = 1L;
	private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	@Autowired
	private IBillTypeApi billTypeApi;
	@Autowired
	private IBillCodeApi billCodeApi;
	@Autowired
	private IOrgApi iOrgApi;
	@Autowired
	private IUserApi userApi; //获取用户
	@Autowired
	private ISignMgrService service;

	@Autowired
	private ISignMgrSignatoryService signatoryService;

	@Autowired
	private SessionManager sessionManager;


	/**
	 * 查询签章列表，内部单位
	 *
	 * @param param 请求参数
	 *
	 * @return CommonResponse<IPage < SignMgrVO>>
	 */
	@PostMapping(value = "/queryList")
	public CommonResponse<IPage<SignatureCenterVO>> queryList(@RequestBody QueryParam param) {
		// 请求参数
		logger.info("查询签章列表，请求参数：{}", JSONObject.toJSONString(param, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
		// 校验参数-签章状态（平台内）
		if (param.getParams() == null || param.getParams().get("jobStatus") == null || param.getParams().get("jobStatus").getValue() == null) {
			return CommonResponse.error("请求参数签章状态jobStatus不能为空！");
		}
		// 获取当前登陆用户手机号
		// FIXME: 2022/2/23 同一用户在不同组织下手机号可能不一样，还需要根据组织查询
		// CommonResponse<List<UserVO>> user = userApi.queryListByIds(new String[] {String.valueOf(InvocationInfoProxy.getUserid())});
		// logger.info("当前登陆用户userId：{}，签章中心获取到的当前登陆用户信息：{}", InvocationInfoProxy.getUserid(), JSONObject.toJSONString(user, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
		// if (!user.isSuccess()) {
		// 	return CommonResponse.error(user.getMsg());
		// }
		// if (user.getData().isEmpty()) {
		// 	return CommonResponse.error("当前登陆用户信息不存在!");
		// }
		// String userMobile = user.getData().get(0).getUserMobile();
		// if (StringUtils.isEmpty(userMobile)) {
		// 	return CommonResponse.error("当前登陆用户手机号为空，请联系管理员！");
		// }
		CommonResponse<UserVO> user = userApi.findUserByUserId(InvocationInfoProxy.getUserid());
		logger.info("当前登陆用户userId：{}，签章中心获取到的当前登陆用户信息：{}", InvocationInfoProxy.getUserid(), JSONObject.toJSONString(user, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
		if (!user.isSuccess()) {
			return CommonResponse.error(user.getMsg());
		}
		if (user.getData() == null) {
			return CommonResponse.error("当前登陆用户信息不存在!");
		}
		// fixme: 不可避免的漏洞，用户可以随意更改手机号码
		String userMobile = user.getData().getUserMobile();
		if (StringUtils.isEmpty(userMobile)) {
			return CommonResponse.error("当前登陆用户手机号为空，请联系管理员！");
		}

		// 模糊查询
		String billName = null;
		String billCode = null;
		String contractName = null;
		String projectName = null;
		String useSealType = null;
		String sortField = null;

		if (param.getParams().containsKey("billName") && param.getParams().get("billName").getValue() != null) {
			billName = String.valueOf(param.getParams().get("billName").getValue());
		}
		if (param.getParams().containsKey("billCode") && param.getParams().get("billCode").getValue() != null) {
			billCode = String.valueOf(param.getParams().get("billCode").getValue());
		}
		if (param.getParams().containsKey("contractName") && param.getParams().get("contractName").getValue() != null) {
			contractName = String.valueOf(param.getParams().get("contractName").getValue());
		}
		if (param.getParams().containsKey("projectName") && param.getParams().get("projectName").getValue() != null) {
			projectName = String.valueOf(param.getParams().get("projectName").getValue());
		}
		if (param.getParams().containsKey("useSealType") && param.getParams().get("useSealType").getValue() != null) {
			useSealType = String.valueOf(param.getParams().get("useSealType").getValue());
		}

		// 排序字段
		if ((Integer) param.getParams().get("jobStatus").getValue() == 1) {
			sortField = "t.accept_time";
		} else {
			sortField = "t.end_time";
		}


		// 自定义分页查询子表数据
		Page<SignatureCenterVO> pg = new Page<>(param.getPageIndex(), param.getPageSize());
		IPage<SignatureCenterVO> pageData = signatoryService.querySignCenterPage(pg, InvocationInfoProxy.getTenantid(), userMobile,
				(Integer) param.getParams().get("jobStatus").getValue(),
				billName, billCode, contractName, projectName, useSealType, sortField);

		return CommonResponse.success("查询列表数据成功！", pageData);
	}

	/**
	 * 获取私有云合同签署短链接
	 *
	 * @param privateSignUrlVO VO
	 *
	 * @return privateSignUrl
	 */
	@PostMapping(value = "/getPrivateSignUrl")
	public CommonResponse<String> privateSignUrl(@RequestBody PrivateSignUrlVO privateSignUrlVO) {
		// 验证合同是否在签署中，签署中的才能获取到签署链接，排除过期合同、已完成合同等
		ContractDetail detail = service.detail(privateSignUrlVO.getContractId(), false);
		logger.info("签章中心-查询的合同详情：{}", JSONObject.toJSONString(detail, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
		if (detail == null) {
			CommonResponse.error("查不到当前合同详情！请联系系统管理员！");
		}
		// TODO: 2022/2/24 需要优化：正常都可以获取到签署链接
		switch (detail.getStatus()) {
			case SIGNING:
				break;
			case COMPLETE:
				return CommonResponse.error("当前合同-已完成");
			case EXPIRED:
				return CommonResponse.error("当前合同-已过期");
			case DRAFT:
				return CommonResponse.error("当前合同-草稿");
			case REJECTED:
				return CommonResponse.error("当前合同-已退回");
			case RECALLED:
				return CommonResponse.error("当前合同-已撤回");
			case FILLING:
				return CommonResponse.error("当前合同-拟定中");
			case TERMINATING:
				return CommonResponse.error("当前合同-作废确认中");
			case TERMINATED:
				return CommonResponse.error("当前合同-已作废");
			case DELETE:
				return CommonResponse.error("当前合同-已删除");
			case FINISHED:
				return CommonResponse.error("当前合同-已完成 ");
			case REQUIRED:
				return CommonResponse.error("当前合同-待我处理");
			case WAITING:
				return CommonResponse.error("当前合同-待他人处理");
			case CANCELLED:
				return CommonResponse.error("当前合同-已作废 ");
			default:
				break;
		}

		String privateSignUrl = service.createPrivateSignUrl(privateSignUrlVO.getContractId(), privateSignUrlVO.getTenantType(), privateSignUrlVO.getTenantName(), privateSignUrlVO.getContact());
		return CommonResponse.success("获取私有云合同签署短链接，成功！", privateSignUrl);
	}

}

==> ejc-signaturemanage-impl-3.0.1-20220804.080952-207-sources.jar: com/ejianc/business/signaturemanage/controller/SignMgrController.java <==
package com.ejianc.business.signaturemanage.controller;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.signaturemanage.service.ISignMgrService;
import com.ejianc.business.signaturemanage.service.ISignMgrSignatoryService;
import com.ejianc.business.signaturemanage.vo.PrivateSignUrlVO;
import com.ejianc.business.signaturemanage.vo.SignatureCenterVO;
import com.ejianc.foundation.orgcenter.api.IUserApi;
import com.ejianc.foundation.support.api.IParamConfigApi;
import com.ejianc.foundation.support.vo.ParamRegisterSetVO;
import com.ejianc.foundation.usercenter.vo.UserVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import net.qiyuesuo.sdk.bean.contract.ContractDetail;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.io.Serializable;

/**
 * 签章中心
 */
@RestController
@RequestMapping("/signatureCenter")
public class SignMgrController implements Serializable {
	private static final long serialVersionUID = 1L;
	private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改
	private final Logger logger = LoggerFactory.getLogger(this.getClass());
	@Autowired
	private IUserApi userApi; //获取用户
	@Autowired
	private ISignMgrService service;

	@Autowired
	private ISignMgrSignatoryService signatoryService;

    @Autowired
    private IParamConfigApi paramConfigApi;


    private final String FACE_SIGN_SIGNAL = "P-n0dc750133";

	/**
	 * 查询签章列表，内部单位
	 *
	 * @param param 请求参数
	 *
	 * @return CommonResponse<IPage < SignMgrVO>>
	 */
	@PostMapping(value = "/queryList")
	public CommonResponse<IPage<SignatureCenterVO>> queryList(@RequestBody QueryParam param) {
		// 请求参数
		logger.info("查询签章列表，请求参数：{}", JSONObject.toJSONString(param, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
		// 校验参数-签章状态（平台内）
		if (param.getParams() == null || param.getParams().get("jobStatus") == null || param.getParams().get("jobStatus").getValue() == null) {
			return CommonResponse.error("请求参数签章状态jobStatus不能为空！");
		}
		// 获取当前登陆用户手机号
		// FIXME: 2022/2/23 同一用户在不同组织下手机号可能不一样，还需要根据组织查询
		// CommonResponse<List<UserVO>> user = userApi.queryListByIds(new String[] {String.valueOf(InvocationInfoProxy.getUserid())});
		// logger.info("当前登陆用户userId：{}，签章中心获取到的当前登陆用户信息：{}", InvocationInfoProxy.getUserid(), JSONObject.toJSONString(user, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
		// if (!user.isSuccess()) {
		// 	return CommonResponse.error(user.getMsg());
		// }
		// if (user.getData().isEmpty()) {
		// 	return CommonResponse.error("当前登陆用户信息不存在!");
		// }
		// String userMobile = user.getData().get(0).getUserMobile();
		// if (StringUtils.isEmpty(userMobile)) {
		// 	return CommonResponse.error("当前登陆用户手机号为空，请联系管理员！");
		// }
		CommonResponse<UserVO> user = userApi.findUserByUserId(InvocationInfoProxy.getUserid());
		logger.info("当前登陆用户userId：{}，签章中心获取到的当前登陆用户信息：{}", InvocationInfoProxy.getUserid(), JSONObject.toJSONString(user, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
		if (!user.isSuccess()) {
			return CommonResponse.error(user.getMsg());
		}
		if (user.getData() == null) {
			return CommonResponse.error("当前登陆用户信息不存在!");
		}
		// fixme: 不可避免的漏洞，用户可以随意更改手机号码
		String userMobile = user.getData().getUserMobile();
		if (StringUtils.isEmpty(userMobile)) {
			return CommonResponse.error("当前登陆用户手机号为空，请联系管理员！");
		}

		// 模糊查询
		String billName = null;
		String billCode = null;
		String contractName = null;
		String projectName = null;
		String useSealType = null;
		String sortField = null;

		if (param.getParams().containsKey("billName") && param.getParams().get("billName").getValue() != null) {
			billName = String.valueOf(param.getParams().get("billName").getValue());
		}
		if (param.getParams().containsKey("billCode") && param.getParams().get("billCode").getValue() != null) {
			billCode = String.valueOf(param.getParams().get("billCode").getValue());
		}
		if (param.getParams().containsKey("contractName") && param.getParams().get("contractName").getValue() != null) {
			contractName = String.valueOf(param.getParams().get("contractName").getValue());
		}
		if (param.getParams().containsKey("projectName") && param.getParams().get("projectName").getValue() != null) {
			projectName = String.valueOf(param.getParams().get("projectName").getValue());
		}
		if (param.getParams().containsKey("useSealType") && param.getParams().get("useSealType").getValue() != null) {
			useSealType = String.valueOf(param.getParams().get("useSealType").getValue());
		}

		// 排序字段
		if ((Integer) param.getParams().get("jobStatus").getValue() == 1) {
			sortField = "t.accept_time";
		} else {
			sortField = "t.end_time";
		}


		// 自定义分页查询子表数据
		Page<SignatureCenterVO> pg = new Page<>(param.getPageIndex(), param.getPageSize());
		IPage<SignatureCenterVO> pageData = signatoryService.querySignCenterPage(pg, InvocationInfoProxy.getTenantid(), userMobile,
				(Integer) param.getParams().get("jobStatus").getValue(),
				billName, billCode, contractName, projectName, useSealType, sortField);

		return CommonResponse.success("查询列表数据成功！", pageData);
	}

	/**
	 * 获取私有云合同签署短链接
	 *
	 * @param privateSignUrlVO VO
	 *
	 * @return privateSignUrl
	 */
	@PostMapping(value = "/getPrivateSignUrl")
	public CommonResponse<String> privateSignUrl(@RequestBody PrivateSignUrlVO privateSignUrlVO) {
		// 验证合同是否在签署中，签署中的才能获取到签署链接，排除过期合同、已完成合同等
		ContractDetail detail = service.detail(privateSignUrlVO.getContractId(), false);
		logger.info("签章中心-查询的合同详情：{}", JSONObject.toJSONString(detail, SerializerFeature.PrettyFormat, SerializerFeature.WriteMapNullValue));
		if (detail == null) {
			CommonResponse.error("查不到当前合同详情！请联系系统管理员！");
		}
		// TODO: 2022/2/24 需要优化：正常都可以获取到签署链接
		switch (detail.getStatus()) {
			case SIGNING:
				break;
			case COMPLETE:
				return CommonResponse.error("当前合同-已完成");
			case EXPIRED:
				return CommonResponse.error("当前合同-已过期");
			case DRAFT:
				return CommonResponse.error("当前合同-草稿");
			case REJECTED:
				return CommonResponse.error("当前合同-已退回");
			case RECALLED:
				return CommonResponse.error("当前合同-已撤回");
			case FILLING:
				return CommonResponse.error("当前合同-拟定中");
			case TERMINATING:
				return CommonResponse.error("当前合同-作废确认中");
			case TERMINATED:
				return CommonResponse.error("当前合同-已作废");
			case DELETE:
				return CommonResponse.error("当前合同-已删除");
			case FINISHED:
				return CommonResponse.error("当前合同-已完成 ");
			case REQUIRED:
				return CommonResponse.error("当前合同-待我处理");
			case WAITING:
				return CommonResponse.error("当前合同-待他人处理");
			case CANCELLED:
				return CommonResponse.error("当前合同-已作废 ");
			default:
				break;
		}

        // 水印系统参数
        String contract = privateSignUrlVO.getContact();
		boolean needContact = false;
        CommonResponse<ParamRegisterSetVO> response = paramConfigApi.getByCode(FACE_SIGN_SIGNAL);
        if (!response.isSuccess()) {
            logger.error("获取水印系统参数请求失败，失败原因：", JSONObject.toJSONString(response));
        }
        if("1".equals(response.getData().getValueData())) {
            needContact = true;
        }
        if(needContact && StringUtils.isBlank(contract)) {
            //查找当前操作用户的联系方式
            CommonResponse<UserVO> userResp = userApi.findUserByUserId(InvocationInfoProxy.getUserid());
            if(!userResp.isSuccess()) {
                logger.error("获取签署连接失败，查询当前用户-[{}]联系方式失败, {}", InvocationInfoProxy.getUserid(), JSONObject.toJSONString(userResp));
                throw new BusinessException("获取签署连接失败，查询当前用户联系方式失败！");
            }

            if(StringUtils.isBlank(userResp.getData().getUserMobile())) {
                logger.error("获取签署连接失败，查询当前用户-[{}]联系方式为空!");
                throw new BusinessException("获取签署连接失败，查询当前用户联系方式为空！");
            }
            contract = userResp.getData().getUserMobile();
        }

		String privateSignUrl = service.createPrivateSignUrl(privateSignUrlVO.getContractId(), privateSignUrlVO.getTenantType(), privateSignUrlVO.getTenantName(), contract);
		return CommonResponse.success("获取私有云合同签署短链接，成功！", privateSignUrl);
	}

}
